# -------------------------------------------------------------------------------------
# flo::editor::Discussion
# -------------------------------------------------------------------------------------
# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
# Copyright : (c) MKDoc Holdings Ltd, 2003
# -------------------------------------------------------------------------------------
package flo::editor::Discussion;
use flo::plugin::Discussion::IMAP;
use Text::Unidecode;
use MKDoc::Config;
use flo::Editor;
use flo::Standard;
use MKDoc::CGI;
use MKDoc::Util::Text2HTML;
use MKDoc::XML::Dumper;
use Unicode::Normalize;
use strict;
use flo::Component;
use utf8;

use base qw /flo::Component
	     flo::editor::Mixin::compute_name
	     flo::editor::Mixin::normalize_name/;


sub preferred_extension { 'html' }


sub activate
{
    my $self = shift;
    return unless ($self->SUPER::activate (@_));
    return MKDoc::Config->IMAP_SERVER;
}


##
# $class->new;
# ------------
#   Instanciates a new flo::Editor::Discussion component object
##
sub new
{
    my $class = shift;
    $class    = ref $class || $class;
    my $self  = bless { @_ }, $class;
    
    my $cgi = $self->{cgi};
    my $param_name = $self->{param_name};

    $self->{mbox}        = '';
    $self->{title}       = '';
    $self->{description} = '';
    
    if (defined $cgi and not defined $cgi->param ($param_name . "_add"))
    {
	my $mbox        = $cgi->param ($param_name . "_mbox")        || '';
	my $title       = $cgi->param ($param_name . "_title")       || '';
	my $description = $cgi->param ($param_name . "_description") || '';
	$self->set_mbox        ($mbox);
	$self->set_title       ($title);
	$self->set_description ($description);
    }
    
    $self->{class} = 'discussion';
    return $self;
}


##
# $self->mbox;
# ------------
#   Sets the IMAP mbox which is associated with that component.
##
sub mbox
{
    my $self = shift;
    return $self->{mbox};
}


##
# $self->set_mbox ($mbox_name);
# -----------------------------
#   $mbox_name - name of the mbox to set
##
sub set_mbox
{
    my $self = shift;
    my $mbox = shift; # u_shift
    $self->{mbox} = unidecode (join ' ', split /(?:\n|\r)/, $mbox);
    $self->{mbox} =~ s/^\s+//;
    $self->{mbox} =~ s/\s+$//;
    $self->{mbox} =~ s/[^a-z0-9]/\./g;
    $self->{mbox} =~ s/\.+/\-/g;
}


##
# $self->title;
# -------------
#   Gets the title attribute of that component
##
sub title
{
    my $self = shift;
    return $self->{title};
}


##
# $self->set_title ($title);
# --------------------------
#   $title - the title to set
#
#   Gets the title attribute of that component
##
sub set_title
{
    my $self = shift;
    my $title = shift; # u_shift
    $self->{title} = join ' ', split /(?:\n|\r)/, $title;
    $self->{title} =~ s/^\s+//;
    $self->{title} =~ s/\s+$//;
}


##
# $self->description;
# -------------------
#   Gets the description attribute of that component
##
sub description
{
    my $self = shift;
    return $self->{description};
}


##
# $self->set_description ($description);
# --------------------------------------
#   $description - the description to set
#
#   Gets the description attribute of that component
##
sub set_description
{
    my $self = shift;
    my $description = shift; # u_shift
    $self->{description} = join ' ', split /(?:\n|\r)/, $description;
    $self->{description} =~ s/^\s+//;
    $self->{description} =~ s/\s+$//;
}


##
# $self->generate_xml;
# --------------------
#   Serializes the object to XML
##
sub generate_xml
{
    my $self = shift;
    
    # makes sure that the mbox exists
    my $imap = new flo::plugin::Discussion::IMAP;
    $imap->mbox_create ($self->mbox);

    my $cgi = delete ($self->{cgi});
    my $param_name = delete ($self->{param_name});
    my $res = $self->SUPER::generate_xml (@_);
    $self->{cgi} = $cgi;
    $self->{param_name} = $param_name;
    return $res;
}


##
# $self->html; (DEPRECATED)
# ------------
#   Returns an HTML view of this component
##
sub html
{
    my $self = shift;
    return 'Discussion ' . $self->mbox;
}


sub to_html { return shift->html }


1;
