# -------------------------------------------------------------------------------------
# flo::plugin::Account::Reminder
# -------------------------------------------------------------------------------------
#       Author : Steve Purkis <spurkis@mkdoc.com>
#    Copyright : (c) 2002, MKDoc Holdings Ltd.
#      Version : $Id: Reminder.pm,v 1.14.2.6 2003/06/09 17:05:44 jhiver Exp $
#
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden.
#
# flo::plugin::Account::Reminder - Account reminder plugin for MKDoc.
# This plugin lets an existing user receive their account details by email.
# -------------------------------------------------------------------------------------
package flo::plugin::Account::Reminder;
use flo::Standard qw /cgi/;
use flo::Record::Editor;

use MKDoc::Ouch;
use MKDoc::XML::Mail;
use MKDoc::Mailer;

use Carp;
use Petal;

use strict;
use 5.008_000;
use utf8;


use base qw /flo::Plugin/;


sub template_path { '/account/reminder' }


##
# $self->http_get;
# ----------------
# Displays the form which lets the editor choose which audiences
# the current document relates to.
##
sub http_get
{
    my $self = shift;
    $self->render_http (
	self       => $self,
	object     => $self->parent,
	__input__  => 'XML',
	__output__ => 'XHTML',
       );    
    return 'TERMINATE';
}


##
# $self->http_post;
# -----------------
# Reflect the changes on the database and redirects to
# current document.
##
sub http_post
{
    my $self = shift;
    my $cgix = flo::Standard::cgi()->new;
    my $data = $cgix->param ('q') or do {
	new MKDoc::Ouch 'reminder/no_data';
	return $self->http_get;
    };
    
    my $editor_t = flo::Standard::table ('Editor');
    my $condition = new lib::sql::Condition();
    $condition->boolean ('OR');
    $condition->add ('Login', '=', $data);
    $condition->add ('Email', '=', $data);
    
    my $query = $editor_t->search ($condition);
    my $count = 0;
    while (my $editor = $query->next())
    {
	$self->{user} = $editor;
	$self->_send_mail();
	$count++;
    }
    
    $self->{is_post} = 1;
    $self->{count}   = $count;
    $count == 0 and do {
	new MKDoc::Ouch 'reminder/no_match';
    };
    
    return $self->http_get;
}


sub user
{
    my $self = shift;
    return $self->{user};
}


##
# $self->_send_mail;
# ------------------
# Sends the email...
##
sub _send_mail
{
    my $self   = shift;
    local *flo::plugin::Account::Reminder::template_path;
    *flo::plugin::Account::Reminder::template_path = sub { '/account/emails/reminder' };
    
    my $xml_mail = eval {
	$self->render (
	    self       => $self,
	    object     => $self->parent(),
	    __input__  => 'XML',
	    __output__ => 'XML',
	   );
    };
    defined $@ and $@ and do {
	warn $@;
	new MKDoc::Ouch 'mail/cannot_create';
	return 0;
    };
    
    eval {
	my $txt_mail = MKDoc::XML::Mail->process ($xml_mail);
	my $mail = new MKDoc::Mailer ($txt_mail);
	$mail->send();
    };
    defined $@ and $@ and do {
	warn $@;
	new MKDoc::Ouch 'mail/cannot_send';
	return 0;
    };
}


1;


__END__
